package java.security.cert;

import java.security.InvalidParameterException;
import java.security.KeyStoreException;
import java.security.KeyStore;
import java.security.InvalidAlgorithmParameterException;
import java.util.Set;

public class PKIXBuilderParameters extends PKIXParameters
{
    private int maxPathLength;
    
    public PKIXBuilderParameters(Set<TrustAnchor> set, CertSelector targetCertConstraints) throws InvalidAlgorithmParameterException {
        super(set);
        this.maxPathLength = 5;
        this.setTargetCertConstraints(targetCertConstraints);
    }
    
    public PKIXBuilderParameters(KeyStore keyStore, CertSelector targetCertConstraints) throws KeyStoreException, InvalidAlgorithmParameterException {
        super(keyStore);
        this.maxPathLength = 5;
        this.setTargetCertConstraints(targetCertConstraints);
    }
    
    public void setMaxPathLength(int maxPathLength) {
        if (maxPathLength < -1) {
            throw new InvalidParameterException("the maximum path length parameter can not be less than -1");
        }
        this.maxPathLength = maxPathLength;
        return;
    }
    
    public int getMaxPathLength() {
        return this.maxPathLength;
    }
    
    @Override
    public String toString() {
        StringBuffer sb = new StringBuffer();
        sb.append("[\n");
        sb.append(super.toString());
        sb.append("  Maximum Path Length: " + this.maxPathLength + "\n");
        sb.append("]\n");
        return sb.toString();
    }
}
